@@ -88,6 +88,12 @@
  * </refsect2>
  * <refsect2>
  *   <title>Search and Replace</title>
+ *   <warning>
+ *     <para>
+ *       The search and replace API is unstable and will most probably
+ *       change in the near future.
+ *     </para>
+ *   </warning>
  *   <para>
  *     To set the text to search, use gtk_source_buffer_set_search_text(). The
  *     search occurrences will be highlighted, and the total number of
@@ -162,6 +168,7 @@ enum {
 	PROP_CAN_REDO,
 	PROP_HIGHLIGHT_SYNTAX,
 	PROP_HIGHLIGHT_MATCHING_BRACKETS,
+	PROP_HIGHLIGHT_SEARCH,
 	PROP_MAX_UNDO_LEVELS,
 	PROP_LANGUAGE,
 	PROP_STYLE_SCHEME,
@@ -320,6 +327,19 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 							       TRUE,
 							       G_PARAM_READWRITE));
 
+	/**
+	 * GtkSourceBuffer:highlight-search:
+	 *
+	 * Whether to highlight search occurrences in the buffer.
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_HIGHLIGHT_SEARCH,
+					 g_param_spec_boolean ("highlight-search",
+							       _("Highlight Search"),
+							       _("Whether to highlight search occurrences"),
+							       TRUE,
+							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
 	/**
 	 * GtkSourceBuffer:max-undo-levels:
 	 *
@@ -406,19 +426,20 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * GtkSourceBuffer:search-occurrences-count:
 	 *
 	 * The total number of search occurrences. If the search is disabled,
-	 * the value is 0.
+	 * the value is 0. If the buffer is not already fully scanned, the value
+	 * is -1.
 	 *
 	 * Since: 3.10
 	 */
 	g_object_class_install_property (object_class,
 					 PROP_SEARCH_OCCURRENCES_COUNT,
-					 g_param_spec_uint ("search-occurrences-count",
-							    _("Search occurrences count"),
-							    _("Total number of search occurrences"),
-							    0,
-							    G_MAXUINT,
-							    0,
-							    G_PARAM_READABLE));
+					 g_param_spec_int ("search-occurrences-count",
+							   _("Search occurrences count"),
+							   _("Total number of search occurrences"),
+							   -1,
+							   G_MAXINT,
+							   0,
+							   G_PARAM_READABLE));
 
 	/**
 	 * GtkSourceBuffer:case-sensitive-search:
@@ -669,12 +690,17 @@ gtk_source_buffer_set_property (GObject      *object,
 	{
 		case PROP_HIGHLIGHT_SYNTAX:
 			gtk_source_buffer_set_highlight_syntax (source_buffer,
-							      g_value_get_boolean (value));
+								g_value_get_boolean (value));
 			break;
 
 		case PROP_HIGHLIGHT_MATCHING_BRACKETS:
 			gtk_source_buffer_set_highlight_matching_brackets (source_buffer,
-								g_value_get_boolean (value));
+									   g_value_get_boolean (value));
+			break;
+
+		case PROP_HIGHLIGHT_SEARCH:
+			_gtk_source_search_set_highlight (source_buffer->priv->search,
+							  g_value_get_boolean (value));
 			break;
 
 		case PROP_MAX_UNDO_LEVELS:
@@ -747,6 +773,10 @@ gtk_source_buffer_get_property (GObject    *object,
 					     source_buffer->priv->highlight_brackets);
 			break;
 
+		case PROP_HIGHLIGHT_SEARCH:
+			g_value_set_boolean (value, _gtk_source_search_get_highlight (source_buffer->priv->search));
+			break;
+
 		case PROP_MAX_UNDO_LEVELS:
 			g_value_set_int (value,
 					 source_buffer->priv->max_undo_levels);
@@ -777,7 +807,7 @@ gtk_source_buffer_get_property (GObject    *object,
 			break;
 
 		case PROP_SEARCH_OCCURRENCES_COUNT:
-			g_value_set_uint (value, _gtk_source_search_get_occurrences_count (source_buffer->priv->search));
+			g_value_set_int (value, _gtk_source_search_get_occurrences_count (source_buffer->priv->search));
 			break;
 
 		case PROP_CASE_SENSITIVE_SEARCH:
@@ -2852,16 +2882,63 @@ gtk_source_buffer_get_search_wrap_around (GtkSourceBuffer *buffer)
 	return _gtk_source_search_get_wrap_around (buffer->priv->search);
 }
 
+/**
+ * gtk_source_buffer_set_highlight_search:
+ * @buffer: a #GtkSourceBuffer.
+ * @highlight: the setting.
+ *
+ * Enables or disables search highlighting. If you disable the search
+ * highlighting, you can still use the other search and replace functions.
+ *
+ * Since: 3.10
+ */
+void
+gtk_source_buffer_set_highlight_search (GtkSourceBuffer *buffer,
+					gboolean         highlight)
+{
+	gboolean cur_val;
+
+	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
+
+	highlight = highlight != FALSE;
+
+	cur_val = _gtk_source_search_get_highlight (buffer->priv->search);
+
+	if (cur_val != highlight)
+	{
+		_gtk_source_search_set_highlight (buffer->priv->search, highlight);
+
+		g_object_notify (G_OBJECT (buffer), "highlight-search");
+	}
+}
+
+/**
+ * gtk_source_buffer_get_highlight_search:
+ * @buffer: a #GtkSourceBuffer.
+ *
+ * Returns: whether to highlight search occurrences.
+ * Since: 3.10
+ */
+gboolean
+gtk_source_buffer_get_highlight_search (GtkSourceBuffer *buffer)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_BUFFER (buffer), FALSE);
+
+	return _gtk_source_search_get_highlight (buffer->priv->search);
+}
+
 /**
  * gtk_source_buffer_get_search_occurrences_count:
  * @buffer: a #GtkSourceBuffer.
  *
- * Gets the total number of search occurrences.
+ * Gets the total number of search occurrences. If the buffer is not already
+ * fully scanned, the total number of occurrences is unknown, and -1 is
+ * returned.
  *
- * Returns: the total number of search occurrences.
+ * Returns: the total number of search occurrences, or -1 if unknown.
  * Since: 3.10
  */
-guint
+gint
 gtk_source_buffer_get_search_occurrences_count (GtkSourceBuffer *buffer)
 {
 	g_return_val_if_fail (GTK_SOURCE_IS_BUFFER (buffer), 0);
@@ -2906,7 +2983,9 @@ gtk_source_buffer_get_search_occurrence_position (GtkSourceBuffer   *buffer,
  * @match_start: (out) (allow-none): return location for start of match, or %NULL.
  * @match_end: (out) (allow-none): return location for end of match, or %NULL.
  *
- * Synchronous forward search.
+ * Synchronous forward search. It is recommended to use the asynchronous
+ * functions instead, to not block the user interface. However, if you are sure
+ * that the @buffer is small, this function is more convenient to use.
  *
  * Returns: whether a match was found.
  * Since: 3.10
@@ -2997,7 +3076,9 @@ gtk_source_buffer_forward_search_finish (GtkSourceBuffer  *buffer,
  * @match_start: (out) (allow-none): return location for start of match, or %NULL.
  * @match_end: (out) (allow-none): return location for end of match, or %NULL.
  *
- * Synchronous backward search.
+ * Synchronous backward search. It is recommended to use the asynchronous
+ * functions instead, to not block the user interface. However, if you are sure
+ * that the @buffer is small, this function is more convenient to use.
  *
  * Returns: whether a match was found.
  * Since: 3.10
@@ -3120,7 +3201,8 @@ gtk_source_buffer_search_replace (GtkSourceBuffer   *buffer,
  * @replace: the replacement text.
  * @replace_length: the length of @replace in bytes, or -1.
  *
- * Replaces all search matches by another text.
+ * Replaces all search matches by another text. It is a synchronous function, so
+ * it can block the user interface.
  *
  * Returns: the number of replaced matches.
  * Since: 3.10
