@@ -200,7 +200,12 @@ void			 gtk_source_buffer_set_search_wrap_around		(GtkSourceBuffer	*buffer,
 
 gboolean		 gtk_source_buffer_get_search_wrap_around		(GtkSourceBuffer	*buffer);
 
-guint			 gtk_source_buffer_get_search_occurrences_count		(GtkSourceBuffer	*buffer);
+void			 gtk_source_buffer_set_highlight_search			(GtkSourceBuffer	*buffer,
+										 gboolean		 highlight);
+
+gboolean		 gtk_source_buffer_get_highlight_search			(GtkSourceBuffer	*buffer);
+
+gint			 gtk_source_buffer_get_search_occurrences_count		(GtkSourceBuffer	*buffer);
 
 gint			 gtk_source_buffer_get_search_occurrence_position	(GtkSourceBuffer	*buffer,
 										 const GtkTextIter	*match_start,
