@@ -135,7 +135,7 @@ struct _GtkSourceSearchPrivate
 
 	gulong idle_scan_id;
 
-	guint occurrences_count;
+	gint occurrences_count;
 
 	GtkTextTag *found_tag;
 
@@ -145,6 +145,7 @@ struct _GtkSourceSearchPrivate
 	GtkTextSearchFlags flags;
 	guint at_word_boundaries : 1;
 	guint wrap_around : 1;
+	guint highlight : 1;
 };
 
 /* Data for the asynchronous forward and backward search tasks. */
@@ -181,6 +182,12 @@ sync_found_tag (GtkSourceSearch *search)
 		return;
 	}
 
+	if (!search->priv->highlight)
+	{
+		_gtk_source_style_apply (NULL, search->priv->found_tag);
+		return;
+	}
+
 	style_scheme = gtk_source_buffer_get_style_scheme (GTK_SOURCE_BUFFER (search->priv->buffer));
 
 	if (style_scheme != NULL)
@@ -1757,12 +1764,34 @@ _gtk_source_search_get_wrap_around (GtkSourceSearch *search)
 	return search->priv->wrap_around;
 }
 
-guint
+void
+_gtk_source_search_set_highlight (GtkSourceSearch *search,
+				  gboolean         highlight)
+{
+	g_return_if_fail (GTK_SOURCE_IS_SEARCH (search));
+
+	search->priv->highlight = highlight;
+
+	if (search->priv->found_tag != NULL)
+	{
+		sync_found_tag (search);
+	}
+}
+
+gboolean
+_gtk_source_search_get_highlight (GtkSourceSearch *search)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_SEARCH (search), FALSE);
+
+	return search->priv->highlight;
+}
+
+gint
 _gtk_source_search_get_occurrences_count (GtkSourceSearch *search)
 {
 	g_return_val_if_fail (GTK_SOURCE_IS_SEARCH (search), 0);
 
-	return search->priv->occurrences_count;
+	return is_text_region_empty (search->priv->scan_region) ? search->priv->occurrences_count : -1;
 }
 
 gint
@@ -2097,6 +2126,7 @@ _gtk_source_search_replace_all (GtkSourceSearch *search,
 	GtkTextIter match_start;
 	GtkTextIter match_end;
 	guint nb_matches_replaced = 0;
+	gboolean highlight_matching_brackets;
 
 	g_return_val_if_fail (GTK_SOURCE_IS_SEARCH (search), 0);
 	g_return_val_if_fail (replace != NULL, 0);
@@ -2106,6 +2136,17 @@ _gtk_source_search_replace_all (GtkSourceSearch *search,
 		return 0;
 	}
 
+	g_signal_handlers_block_by_func (search->priv->buffer, insert_text_before_cb, search);
+	g_signal_handlers_block_by_func (search->priv->buffer, insert_text_after_cb, search);
+	g_signal_handlers_block_by_func (search->priv->buffer, delete_range_before_cb, search);
+	g_signal_handlers_block_by_func (search->priv->buffer, delete_range_after_cb, search);
+
+	highlight_matching_brackets =
+		gtk_source_buffer_get_highlight_matching_brackets (GTK_SOURCE_BUFFER (search->priv->buffer));
+
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (search->priv->buffer),
+							   FALSE);
+
 	gtk_text_buffer_get_start_iter (search->priv->buffer, &iter);
 
 	gtk_text_buffer_begin_user_action (search->priv->buffer);
@@ -2121,5 +2162,15 @@ _gtk_source_search_replace_all (GtkSourceSearch *search,
 
 	gtk_text_buffer_end_user_action (search->priv->buffer);
 
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (search->priv->buffer),
+							   highlight_matching_brackets);
+
+	g_signal_handlers_unblock_by_func (search->priv->buffer, insert_text_before_cb, search);
+	g_signal_handlers_unblock_by_func (search->priv->buffer, insert_text_after_cb, search);
+	g_signal_handlers_unblock_by_func (search->priv->buffer, delete_range_before_cb, search);
+	g_signal_handlers_unblock_by_func (search->priv->buffer, delete_range_after_cb, search);
+
+	update (search);
+
 	return nb_matches_replaced;
 }
